package com.link.core.util;

import com.link.core.basic.model.EmailInfo;
import java.util.Date;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Properties;
import javax.activation.DataHandler;
import javax.activation.DataSource;
import javax.activation.FileDataSource;
import javax.mail.Authenticator;
import javax.mail.MessagingException;
import javax.mail.PasswordAuthentication;
import javax.mail.Session;
import javax.mail.Transport;
import javax.mail.Message.RecipientType;
import javax.mail.internet.AddressException;
import javax.mail.internet.InternetAddress;
import javax.mail.internet.MimeBodyPart;
import javax.mail.internet.MimeMessage;
import javax.mail.internet.MimeMultipart;
import org.apache.commons.mail.DefaultAuthenticator;
import org.apache.commons.mail.HtmlEmail;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;

public class EmailUtil {
   private static final Logger logger = LogManager.getLogger(EmailUtil.class);

   public static boolean sendEmail(String emailReceiveAddr, String emailMsg, String emailTitle) {
      boolean flag = true;

      try {
         if (StringUtils.isBlank(emailReceiveAddr)) {
            throw new Exception("收件地址不能为空！");
         }

         if (StringUtils.isBlank(emailMsg)) {
            throw new Exception("邮件内容不能为空！");
         }

         if (StringUtils.isBlank(emailTitle)) {
            throw new Exception("邮件标题不能为空！");
         }

         String htmlEmailTemplate = emailMsg;
         HtmlEmail email = new HtmlEmail();
         email.setHostName("smtp.sina.com");
         email.setSmtpPort(465);
         email.setCharset("UTF-8");
         email.setAuthenticator(new DefaultAuthenticator("linkcrm", "handhand"));
         email.setSSLOnConnect(true);
         email.setFrom("linkcrm@sina.com", "Link CRM");
         email.setSubject(emailTitle);
         email.setHtmlMsg(htmlEmailTemplate);
         email.addTo(emailReceiveAddr);
         email.send();
      } catch (Exception var6) {
         Exception e = var6;
         logger.error("EmailUtil捕获异常: ", e);
         flag = false;
      }

      return flag;
   }

   public static boolean send(final EmailInfo emailInfo, Object... args) {
      boolean sendStatus = true;
      Transport transport = null;

      try {
         if (StringUtils.isBlank(emailInfo.getTo())) {
            throw new Exception("收件人不能为空");
         }

         if (StringUtils.isBlank(emailInfo.getContent())) {
            throw new Exception("邮件内容不能为空");
         }

         if (StringUtils.isBlank(emailInfo.getSubject())) {
            throw new Exception("邮件主题不能为空");
         }

         Properties properties = new Properties();
         properties.setProperty("mail.transport.protocol", emailInfo.getProtocol());
         properties.setProperty("mail.smtp.host", emailInfo.getHost());
         properties.setProperty("mail.smtp.port", emailInfo.getPort());
         properties.setProperty("mail.debug", emailInfo.getEnableDebug());
         properties.setProperty("mail.smtp.auth", emailInfo.getEnableAuth());
         Session session = Session.getInstance(properties, new Authenticator() {
            protected PasswordAuthentication getPasswordAuthentication() {
               return new PasswordAuthentication(emailInfo.getUsername(), emailInfo.getPassword());
            }
         });
         session.setDebug(false);
         MimeMessage email = createEmail(emailInfo, session);
         transport = session.getTransport();
         transport.connect();
         transport.sendMessage(email, email.getAllRecipients());
      } catch (Exception var15) {
         Exception e = var15;
         sendStatus = false;
         logger.error("邮件发送失败", e);
      } finally {
         if (transport != null) {
            try {
               transport.close();
            } catch (MessagingException var14) {
               MessagingException e = var14;
               logger.error("Transport对象释放失败", e);
            }
         }

      }

      return sendStatus;
   }

   public static InternetAddress[] getEmailAddress(String emailAddress) throws AddressException {
      String[] addressSplit = emailAddress.split(";");
      int addressCount = addressSplit.length;
      InternetAddress[] addressArray = new InternetAddress[addressCount];

      for(int i = 0; i < addressCount; ++i) {
         if (!StringUtils.isBlank(addressSplit[i])) {
            addressArray[i] = new InternetAddress(addressSplit[i]);
         }
      }

      return addressArray;
   }

   public static MimeMessage createEmail(EmailInfo emailInfo, Session session) throws MessagingException {
      MimeMessage mimeMessage = new MimeMessage(session);
      mimeMessage.setSubject(emailInfo.getSubject());
      mimeMessage.setFrom(new InternetAddress(emailInfo.getFrom()));
      mimeMessage.setRecipients(RecipientType.TO, getEmailAddress(emailInfo.getTo()));
      if (StringUtils.isNotBlank(emailInfo.getToCc())) {
         mimeMessage.setRecipients(RecipientType.CC, getEmailAddress(emailInfo.getToCc()));
      }

      if (StringUtils.isNotBlank(emailInfo.getToBcc())) {
         mimeMessage.setRecipients(RecipientType.BCC, getEmailAddress(emailInfo.getToBcc()));
      }

      MimeMultipart mimeMultipart = new MimeMultipart();
      MimeBodyPart text;
      if ("html".equals(emailInfo.getContentType())) {
         text = new MimeBodyPart();
         text.setContent(emailInfo.getContent(), "text/html;charset=UTF-8");
         mimeMultipart.addBodyPart(text);
      }

      if ("text".equals(emailInfo.getContentType())) {
         text = new MimeBodyPart();
         text.setText(emailInfo.getContent());
         MimeMultipart email = new MimeMultipart();
         email.addBodyPart(text);
         List<String> attachments = emailInfo.getAttachment();
         boolean hasAttachment = null != attachments && !attachments.isEmpty();
         if (hasAttachment) {
            for(int i = 0; i < emailInfo.getAttachment().size(); ++i) {
               MimeBodyPart attachmentBodyPart = new MimeBodyPart();
               DataSource dataSource = new FileDataSource((String)attachments.get(i));
               attachmentBodyPart.setDataHandler(new DataHandler(dataSource));
               attachmentBodyPart.setFileName(dataSource.getName());
               email.addBodyPart(attachmentBodyPart);
            }
         }

         email.setSubType("mixed");
         mimeMessage.setContent(email);
         mimeMessage.setSentDate(new Date());
         mimeMessage.saveChanges();
         return mimeMessage;
      } else {
         Map<String, String> images = emailInfo.getImages();
         boolean hasImages = null != images && images.size() > 0;
         if (hasImages) {
            Iterator var6 = emailInfo.getImages().entrySet().iterator();

            while(var6.hasNext()) {
               Map.Entry<String, String> image = (Map.Entry)var6.next();
               MimeBodyPart imageBodyPart = new MimeBodyPart();
               DataSource dataSource = new FileDataSource((String)image.getValue());
               imageBodyPart.setDataHandler(new DataHandler(dataSource));
               imageBodyPart.setContentID((String)image.getKey());
               mimeMultipart.addBodyPart(imageBodyPart);
            }
         }

         mimeMultipart.setSubType("related");
         MimeBodyPart mimeBodyPart = new MimeBodyPart();
         mimeBodyPart.setContent(mimeMultipart);
         MimeMultipart email = new MimeMultipart();
         email.addBodyPart(mimeBodyPart);
         List<String> attachments = emailInfo.getAttachment();
         boolean hasAttachment = null != attachments && !attachments.isEmpty();
         if (hasAttachment) {
            for(int i = 0; i < emailInfo.getAttachment().size(); ++i) {
               MimeBodyPart attachmentBodyPart = new MimeBodyPart();
               DataSource dataSource = new FileDataSource((String)attachments.get(i));
               attachmentBodyPart.setDataHandler(new DataHandler(dataSource));
               attachmentBodyPart.setFileName(dataSource.getName());
               email.addBodyPart(attachmentBodyPart);
            }
         }

         email.setSubType("mixed");
         mimeMessage.setContent(email);
         mimeMessage.setSentDate(new Date());
         mimeMessage.saveChanges();
         return mimeMessage;
      }
   }
}
